==> win32_Release_v4.0.1_r945.zip: data/scripts/ui/PopupRequestTroops.lua <==
amta  VQ#F7B+Y<3F/ P?O:Jkn:3SSZFqqfAhbhĵ֢􇧚ΣϮ«ꏾNN"&'ts#B-B6szrhHuU;R>4>>>*//0۵ܹͮܲ򗾴z~ҷ~r_<S=[2U9`o
f1X<H  =$'ʣĬik .`l	$}xZ:==3[>_;hnNsSq#f7b't +y6y)z%m(i-h:ڿǯRDULQP޼ɽɦA\CP #&y;n:n!o0 c`v4fz>R"J+6mt	
:47tX.*u_\qdV~8,)׿ֺޜԠ܌з/%QW*+$wqpkv
	/2dbPxP¦ѵ֯feV?<d}r3vrufB-Q7ͩѱ¢Ѿ@F4̡669ldҽ^sulX(-٭ȥ"heˮ޷upV"&NHDj29]tT~^=R>257NQtRSil'"FP<?7R<XR[>P497>=H8\=I,ԧᒹݸ̹˥
 
zlXհ÷Ū
#) u<DYQ4Z.fnw:㺷IJgU\h༿rqZ櫨yW}567S'< ݼѣe1`fcn`b	R=8eE;l.{haFz}Һ\ZSeb
`0B-]n?񵙹ܠ'&%U4F'JcCD%xX:\.	%&*KU~A0ޣ53pϒ)#
8Ȧ9<=e$L*֢2<cAaOaA5Z)]/F(Og'hZ9xԸjkwt@0PTq.
]O.@!F#Q\xZgGLo)
ӲӼjhhj-
{[2\|emlDY3^ªϢ0q'䂢)5<gDǬRyuO<]+Nle`uiGengKo䤮ܹ׳KfG'o`W9=4G3R&S ,H)]<ض٭_4ݰ{-ͻꎪgݚəȻˤʹ­ܹͨ0R=I F/L£ǣıϪخ˹ۣ[lwnL	d7zaadqyDyY~y|}ZX\X*O.]2\||n1P3G.X=b< o lg~Rr	rUswl})%2m94mf	#duU`@&T;Vtƪټײܳơɖힾߙ+cWմͨAl"SXxu;881\=V3qutg+F#P#B%@`cy
ۇgbM׳,=||_˸}5`dabu_啗۵ѴAf¯<t.)ĄrU)uvXA|jF)*H|W*fk`7^*BgJ'F!DlN>+ϻ--,)	+C6R
kj5B*C7Rp\<-%&$8(7*B@xjH|㛡aoM /))ڳ"<7Seo.J.k
km1E7B`GjGjJm䐳_a`HxVdjRvwt7X4[)*-utSCfwRpRP~nLkֵޫ`	dngGt|u[[Zh֮abkXiSR3JuA@𘑳;R?M,w0c@@h
8<455?|GйԳ1
mlNzx[]t!$cY~]c
g lKVT6W9W2L2	
CèPV|(#JN=X{	oF7:BDGh)+ܰ٩۾Ӑ²qpuR~^mAaL}U2< '31ϷL5^.ĕ~z	A$H8]/S١_p<_354xk,ّsw:z0Xў:O;Z(jx5}x:O&J.G)N{75SZ3Uu[S;XUW$
m|ؚ㏁-,)|{
S0)+֒K3*+"00LDFW6~+(Td	fd@eMGd -MAFעÜɥʫϪ˝GWtٴխUU%iˮֶ<=T7X6z!#<}mEv?dDjj{kiG\Ah0=ԼD[1Ibϗ/HE=)AQg-	hsTSeLB@hJT]3p "S3l[3Z(Mbji6T Ns	VUVdUyYkZ|93<Q^d@y1ϣ_ꆗ籙kU~zvPˍƂdRp^w_[y͇y^r>BKBfW}tSv*vN2<6`lsxPrby	}!TrJ&$xpxH&C4vb@q鞼%#GCowX''  'RjI䜳g*S}]A0$
ܹw]e`P KyY^r|}U<2̔|r@+ɡdGs#ǟҮ:^`8Q72[-XqS߿{O".s[ƶ²ކ?׏йʫɥbRrdũ,;K98Z(M,
@ݩdDFJ: e~<zwaHB'I-<<<

==> win32_Release_v4.0.2_r971.zip: data/scripts/ui/PopupRequestTroops.lua <==
amta  VQ#F7B+Y<3F/ P?O:Jkn:3SSZFqqfAhbhĵ֢􇧚ΣϮ«ꏾNN"&'ts#B-B6szrhHuU;R>4>>>*//0۵ܹͮܲ򗾴z~ҷ~r_<S=[2U9`o
f1X<H  =$'ʣĬik .`l	$}xZ:==3[>_;hnNsSq#f7b't +y6y)z%m(i-h:ڿǯRDULQP޼ɽɦA\CP #&y;n:n!o0 c`v4fz>R"J+6mt	
:47tX.*u_\qdV~8,)׿ֺޜԠ܌з/%QW*+$wqpkv
	/2dbPxP¦ѵ֯feV?<d}r3vrufB-Q7ͩѱ¢Ѿ@F4̡669ldҽ^sulX(-٭ȥ"heˮ޷upV"&NHDj29]tT~^=R>257NQtRSil'"FP<?7R<XR[>P497>=H8\=I,ԧᒹݸ̹˥
 
zlXհ÷Ū
#) u<DYQ4Z.fnw:㺷IJgU\h༿rqZ櫨yW}567S'< ݼѣe1`fcn`b	R=8eE;l.{haFz}Һ\ZSeb
`0B-]n?񵙹ܠ'&%U4F'JcCD%xX:\.	%&*KU~A0ޣ53pϒ)#
8Ȧ9<=e$L*֢2<cAaOaA5Z)]/F(Og'hZ9xԸjkwt@0PTq.
]O.@!F#Q\xZgGLo)
ӲӼjhhj-
{[2\|emlDY3^ªϢ0q'䂢)5<gDǬRyuO<]+Nle`uiGengKo䤮ܹ׳KfG'o`W9=4G3R&S ,H)]<ض٭_4ݰ{-ͻꎪgݚəȻˤʹ­ܹͨ0R=I F/L£ǣıϪخ˹ۣ[lwnL	d7zaadqyDyY~y|}ZX\X*O.]2\||n1P3G.X=b< o lg~Rr	rUswl})%2m94mf	#duU`@&T;Vtƪټײܳơɖힾߙ+cWմͨAl"SXxu;881\=V3qutg+F#P#B%@`cy
ۇgbM׳,=||_˸}5`dabu_啗۵ѴAf¯<t.)ĄrU)uvXA|jF)*H|W*fk`7^*BgJ'F!DlN>+ϻ--,)	+C6R
kj5B*C7Rp\<-%&$8(7*B@xjH|㛡aoM /))ڳ"<7Seo.J.k
km1E7B`GjGjJm䐳_a`HxVdjRvwt7X4[)*-utSCfwRpRP~nLkֵޫ`	dngGt|u[[Zh֮abkXiSR3JuA@𘑳;R?M,w0c@@h
8<455?|GйԳ1
mlNzx[]t!$cY~]c
g lKVT6W9W2L2	
CèPV|(#JN=X{	oF7:BDGh)+ܰ٩۾Ӑ²qpuR~^mAaL}U2< '31ϷL5^.ĕ~z	A$H8]/S١_p<_354xk,ّsw:z0Xў:O;Z(jx1y{SED7jh!4JJ,7Jl5-0/ںu45Y٬͒ǫĥtwr&Ivp}\]0Q){yPξsxiqD85푍4:".31xtiO29ԁφ4Q9-lA@bNf>?ry^45иپ2/_vpqv`Okh̅::Gѡ󗘛Ĭŷҍ˿юCoOe޺>88C;"JCʔ\߾ݸ͕C#kLCk{z=?8.3;\#
:x_$8_w]
EvֻՄp׹߰ܗԌ>óָйɽᔲ⸰޸׈ڶâЏPV~֎FSq7S{Y--Qhm&
*Q=\>&#r~~\!*kY .جW 4Ϋ[qIL|,eWwp\RS{ldу勮Nc%2ZMyU5F>O*'.	Qfl ^"/>?5璵{)@3Z8T1챙}.BCg/tuUTXlLI+*K2@8 rA--FqR.1ceBrE,_>\0U182 
fJi)cR>?ܮͿڻ`v9ꏦɧ
